#include "ConsensusManager.hh"
#include "version.h"

int main(int argc, char ** argv)
{
  int retval = 0;
  string infile;

  Foundation * tf = NULL;

  try
  {
    string version = RequestManager::getVersionString(gVersionStr,
                                                      gRevisionStr);

    char defaultAmbiguity[16];
    snprintf(defaultAmbiguity, sizeof(defaultAmbiguity), "%d", 
             ConsensusManager::getDefaultAmbiguityMode());

    string dependencies = "xerces";
    string helptext = (string)
"Recalls the consensus and calculates quality classes or consensus quality\n"
"values.\n"
"\n"
"By default, the SliceService recalls the consensus and calculates the quality\n"
"classes of the slices. Specifying any of -v, -q, -c, or their associated\n"
"SimpleOptions will cause SliceService to perform only what is specified.\n"
"\n"
"Output is into a raw Consensus block which needs an XML header and to be put\n"
"into a Response block to be a valid XML file.\n"
"\n"
"The default ambiguity mode is " + defaultAmbiguity +".\n"
"\n"
"   Usage: SliceService [options] slice.xml\n"
"\n"
"     slice.xml Slice XML file\n"
"\n"
"   SliceService Options\n"
"   ------------------\n"
"   -v|--qualityvalue Calculate the consensus quality value\n"
"   -q|--qualityclass Calculate the quality class\n"
"   -f|--editflags    Calculate the edit flags\n"
"   -c|--consensus    Recall the consensus (Same as the Slice Option)\n"
 + RequestManager::getOptionHelp();

    // Instantiate a new Foundation object
    tf = new Foundation (version, helptext, dependencies, argc, argv);
    tf->disableOptionHelp();

    ConsensusManager::handleOptions(tf);
    ConsensusManager manager;

    // Read the input filename
    if ((infile = tf->getOptions()->getNextOtherData()) == "")
    {
      throw Exception("You must specify an input file", "SliceService");
    }

    // Process the file
    retval = manager.processFile(infile, manager.getOutputStream());
  }
  catch (const ExitProgramNormally & e)
  {
    retval = 0;
  }
  catch (const Exception & e)
  {
    cerr << e << endl;
    retval = 100;
  }

  try
  {
    if (tf) delete tf;
  }
  catch (const Exception & e)
  {
    cerr << "Exception while deleting tf: " << e << endl;
    retval = 105;
  }

  return retval;
}
