#ifndef CONTIG_HH
#define CONTIG_HH 1

#include "RequestManager.hh"
#include "Foundation.hh"

#include <vector>
#include <map>
#include <deque>
#include <set>

#include "ContigSequence.hh"
#include "ContigTile.hh"

using libSlice::SliceData;
using libSlice::ConsensusData;

typedef map<string, int> ReadMap;

enum PrintType
{
  SLICE,
  TCOV,
  CONTIG
};


class Contig
{
public:
  Contig(long index, long gindex, ReadManager * readManager, bool verbose);
  ~Contig();

  const string & getName() const;

  void addSlice(SliceData * slice);

  void printContig(ostream & out, PrintType displayType = SLICE);
  void dumpAlignment();
  void dumpRange(long gindexstart, long gindexend, 
                 ContigSequence * read = NULL);

  int calculateCQV(long gindex, char & cons);
  void recallCons();

  ContigSequenceSlice & getTilingSlice(long gindex);

  void addContigSequence(ContigSequence * read);

  void addReadToTiling(ContigSequence * read, 
                       long gindex, 
                       int numPositions=1);
 

  string & getConsensus();
  ReadVector & getReadVector();
  long getWidth();

  void stripSequenceEdgeGaps();
  void stripGapSlices();

  ContigSequence * getContigSequence(const string & seqname);
  ContigSequence * newContigSequence(ReadData * rd, long gindex);

  long shiftContigRight(int distance);
  long widenContig(int distance);
  long trimContigRight(int newContigSize);
  long trimContigLeft(int trimBases);

  long insertGapSlice(long gindex, ContigSequence * read = NULL);

  string getUngappedConsensus(long int startindex, long int length);
  long getGappedIndex(long int ungappedIndex);
  long getUngappedIndex(long int gappedIndex);

  void loadContig(ifstream * cf);


private:

  void printPos(long gindexstart, long gindexend);

  void printSlice(ostream & out, SliceData * slice);
  void printSliceTcov(ostream & out, SliceData * slice);

  long m_newIndex;
  long m_newGindex;

  long m_sliceRangeIndex;
  long m_sliceRangeGindex;

  long m_gindex;
  int m_readCount;

  string m_consensus;

  ReadMap m_readMap;
  ReadVector m_readVector;

  ContigTile m_tiling;
  ReadManager * m_readManager;
  bool m_deleteReadManager;
  string m_contigName;

  bool m_verbose;
};

#endif
