#include "SliceTranslator.hh"

SliceTranslator::SliceTranslator() : RequestManager("SliceTranslator")
{
  m_log.debugL("Contructed SliceTranslator");
  m_log.setMessageLevel(MESSAGE_LEVEL_DEBUG_MEDIUM);
}

SliceTranslator::~SliceTranslator()
{
  m_log.debugL("Destructed SliceTranslator");
}

void SliceTranslator::addSliceRange(long & index, long & gindex)
{
  m_out << "  </ReadCollection>" << endl;

  m_out << "  <SliceRange Index=\"" << m_newSliceRangeIndex
        << "\" Gindex=\""           << m_newSliceRangeGindex
        << "\">" << endl;

  index = gindex = 0L;
}

void SliceTranslator::addSlice(SliceData * slice)
{
  RequestManager::addSlice(slice);

  char consensus = slice->getConsensus();

  long coordinate = m_newIndex;
  if (coordinate && consensus == '-') coordinate--;

  slice->resetIndex(coordinate, m_newGindex);

  slice->printXML(m_out);

  if (consensus != '-') m_newIndex++;
  m_newGindex++;

  delete slice;
}

void SliceTranslator::setTranslationCoordinates(long index, long gindex)
{
  m_newIndex = index;
  m_newGindex = gindex;
}

void SliceTranslator::addReadData(ReadData * readData)
{
  readData->printXML(m_out);
}

void SliceTranslator::addRequest(ConsensusRequest * request)
{
  RequestManager::addRequest(request);

  printXMLHeader(request);

  m_out << "  <ReadCollection>" << endl;
}

int SliceTranslator::printResults()
{
  m_out << "  </SliceRange>" << endl
         << "</Request>"      << endl;

  return m_errorCount;
}

void SliceTranslator::handleOptions(Foundation * tf)
{
  tf->getOptions()->addOptionResult("index|i=i", &m_newIndex,
                                    "Set the new Slice index start");

  tf->getOptions()->addOptionResult("gindex|g=i", &m_newGindex,
                                    "Set the new Slice Gindex start");

  tf->getOptions()->addOptionResult("sindex|x=i", &m_newSliceRangeIndex,
                                    "Set a new SliceRange index");

  tf->getOptions()->addOptionResult("sgindex|y=i", &m_newSliceRangeGindex,
                                    "Set a new SliceRange Gindex");

  RequestManager::handleOptions(tf);
}

// Static Variables
int SliceTranslator::m_newIndex(0);
int SliceTranslator::m_newGindex(0);
int SliceTranslator::m_newSliceRangeIndex(0);
int SliceTranslator::m_newSliceRangeGindex(0);
