#include "SliceTranslator.hh"
#include "version.h"

int main(int argc, char ** argv)
{
  int retval = 0;
  string infile;

  Foundation * tf = NULL;

  try
  {
    string version = RequestManager::getVersionString(gVersionStr,
                                                      gRevisionStr);

    string dependencies = "xerces";
    string helptext = 
"Translates the coordinates of Slices and SliceRanges to new values.\n"
"\n"
"   Usage: trSlice [options] slice.xml\n"
"\n"
"     slice.xml Slice XML file\n"
"\n"
"   trSlice Options\n"
"   ------------------\n"
"   -i|--index  Set the new Slice Index start\n"
"   -g|--gindex Set the new Slice Gindex start\n"
"\n"
"   -x|--sindex  Set the new SliceRange Index\n"
"   -y|--sgindex Set the new SliceRange Gindex\n"
 + RequestManager::getOptionHelp();

    // Instantiate a new Foundation object
    tf = new Foundation (version, helptext, dependencies, argc, argv);
    tf->disableOptionHelp();

    SliceTranslator::handleOptions(tf);
    SliceTranslator manager;

    // Read the input filename
    if ((infile = tf->getOptions()->getNextOtherData()) == "")
    {
      throw Exception("You must specify a slice file", "trSlice");
    }

    // Process the file
    retval = manager.processFile(infile, cerr);
  }
  catch (const ExitProgramNormally & e)
  {
    retval = 0;
  }
  catch (const Exception & e)
  {
    cerr << e << endl;
    retval = 100;
  }

  try
  {
    if (tf) delete tf;
  }
  catch (const Exception & e)
  {
    cerr << "Exception while deleting tf: " << e << endl;
    retval = 105;
  }

  return retval;
}
